@@ -46,6 +46,8 @@ class Blogdocument(Model):
     documenttype = models.ManyToManyField(Documenttype, blank=True, max_length=50, verbose_name="Type de document",related_name='documenttype')
 
     class Meta(Model.Meta):
+        anonymous_perms = []
+        authenticated_perms = ['view, change, add']
         rdf_type = 'blog:document'
 
     def __str__(self):
@@ -57,6 +59,8 @@ class Contactlist(Model):
     thematic = models.ManyToManyField(Thematic, blank=True, max_length=50, verbose_name="Thématique",related_name='contactlist')
 
     class Meta(Model.Meta):
+        anonymous_perms = []
+        authenticated_perms = ['view, change, add']
         rdf_type = 'blog:contactlist'
 
     def __str__(self):
